fisx: Class Hierarchy

fisx

Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 12]

C fisx::Beam | Class describing an X-ray beam
C fisx::Element |
C fisx::Elements | Class handling the physical properties
C ElementsInfo |
C fisx::EPDL97 |
▼C fisx::Layer | Class containing the composition of a layer
C fisx::Detector | Class describing the detector
C fisx::Material | Class containing the composition of a material
C fisx::Math | Common fluorescence spectroscopy math functions
C fisx::Ray |
C fisx::Shell |
C fisx::SimpleIni |
C fisx::SimpleSpecfile |
C fisx::TransmissionTable |
C TrasmissionTable | Class containing a transmission table
C fisx::XRF |
C fisx::XRFConfig |